%bcond_without i18n

Summary:        A lightweight DHCP/caching DNS server
Name:           dnsmasq
Version:        2.89
Release:        5%{?dist}
License:        GPL-2.0-only or GPL-3.0-only
URL:            http://www.thekelleys.org.uk/dnsmasq/
Source0:        http://www.thekelleys.org.uk/dnsmasq/%{name}-%{version}.tar.xz
Source1:        dnsmasq.service
Source2:        dnsmasq-systemd-sysusers.conf
Source3:        http://www.thekelleys.org.uk/dnsmasq/%{name}-%{version}.tar.xz.asc
Source4:        http://www.thekelleys.org.uk/srkgpg.txt

# https://thekelleys.org.uk/gitweb/?p=dnsmasq.git;h=eb92fb32b746f2104b0f370b5b295bb8dd4bd5e5
Patch0001:         dnsmasq-2.89-edns0-size.patch
# http://thekelleys.org.uk/gitweb/?p=dnsmasq.git;a=commit;h=33635d8564f96cedcef9bf9826cbbca76f28aa81
Patch0002:         dnsmasq-2.90-dbus-watchers-bz2186468.patch

Patch3000:      dnsmasq-2.77-underflow.patch
Patch3001:      dnsmasq-2.81-configuration.patch
Patch3002:      dnsmasq-2.78-fips.patch
Patch3003:      backport-CVE-2023-49441-Fix-standalone-SHA256-implementation.patch

BuildRequires:  make gcc pkgconfig
BuildRequires:  dbus-devel libidn2-devel nettle-devel systemd systemd-rpm-macros pkgconfig(libnetfilter_conntrack)
%if %{with i18n}
BuildRequires: gettext
%endif
%{?systemd_ordering}

Requires:       nettle


%description
Dnsmasq is lightweight, easy to configure DNS forwarder and DHCP server.
It is designed to provide DNS and, optionally, DHCP, to a small network.
It can serve the names of local machines which are not in the global
DNS. The DHCP server integrates with the DNS server and allows machines
with DHCP-allocated addresses to appear in the DNS with names configured
either in each host or in a central configuration file. Dnsmasq supports
static and dynamic DHCP leases and BOOTP for network booting of disk-less
machines.

%package        utils
Summary:        Utilities for manipulating DHCP server leases

%description    utils
Utilities that use the standard DHCP protocol to query/remove a DHCP
server's leases.

%if %{with i18n}
%package        langpack
Summary:        Translations for few languages
License:        LicenseRef-Fedora-Public-Domain AND GPL-2.0-or-later
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
# Will not do separate packages for every single language, those translations are small enough
Supplements:    (%{name} = %{version}-%{release} and (langpacks-de or langpacks-es or langpacks-fi or langpacks-fr or langpacks-id or langpacks-it or langpacks-ka or langpacks-no or langpacks-pl or langpacks-pt_BR or langpacks-ro) )

%description    langpack
Translations for few languages on dnsmasq.

%endif


%prep
%autosetup -n %{name}-%{version} -p1
for file in dnsmasq.conf.example man/dnsmasq.8 man/es/dnsmasq.8 src/config.h; do
    sed -i 's|/var/lib/misc/dnsmasq.leases|/var/lib/dnsmasq/dnsmasq.leases|g' "$file"
done

sed -i 's|#define CHUSER "nobody"|#define CHUSER "dnsmasq"|' src/config.h
sed -i 's|#define CHGRP "dip"|#define CHGRP "dnsmasq"|' src/config.h
sed -i "s|\(#\s*define RUNFILE\) \"/var/run/dnsmasq.pid\"|\1 \"%{_rundir}/dnsmasq.pid\"|" src/config.h
sed -i 's|^COPTS[[:space:]]*=|\0 -DHAVE_DBUS -DHAVE_LIBIDN2 -DHAVE_DNSSEC -DHAVE_CONNTRACK|' Makefile

%build
%make_build CFLAGS="$RPM_OPT_FLAGS" LDFLAGS="$RPM_LD_FLAGS" \
%if %{with i18n}
  all-i18n
%else
  all
%endif
%make_build -C contrib/lease-tools CFLAGS="$RPM_OPT_FLAGS" LDFLAGS="$RPM_LD_FLAGS"


%install
mkdir -p %{buildroot}%{_sbindir} \
        %{buildroot}%{_mandir}/man8 \
        %{buildroot}%{_sharedstatedir}/dnsmasq \
        %{buildroot}%{_sysconfdir}/dnsmasq.d \
        %{buildroot}%{_sysconfdir}/dbus-1/system.d
install src/dnsmasq %{buildroot}%{_sbindir}/dnsmasq
install dnsmasq.conf.example %{buildroot}%{_sysconfdir}/dnsmasq.conf
install dbus/dnsmasq.conf %{buildroot}%{_sysconfdir}/dbus-1/system.d/
install -m 644 man/dnsmasq.8 %{buildroot}%{_mandir}/man8/
install -D trust-anchors.conf %{buildroot}%{_datadir}/%{name}/trust-anchors.conf

mkdir -p %{buildroot}%{_bindir} %{buildroot}%{_mandir}/man1
install -m 755 contrib/lease-tools/dhcp_release %{buildroot}%{_bindir}/dhcp_release
install -m 644 contrib/lease-tools/dhcp_release.1 %{buildroot}%{_mandir}/man1/dhcp_release.1
install -m 755 contrib/lease-tools/dhcp_release6 %{buildroot}%{_bindir}/dhcp_release6
install -m 644 contrib/lease-tools/dhcp_release6.1 %{buildroot}%{_mandir}/man1/dhcp_release6.1
install -m 755 contrib/lease-tools/dhcp_lease_time %{buildroot}%{_bindir}/dhcp_lease_time
install -m 644 contrib/lease-tools/dhcp_lease_time.1 %{buildroot}%{_mandir}/man1/dhcp_lease_time.1

mkdir -p %{buildroot}%{_unitdir}
install -m644 %{SOURCE1} %{buildroot}%{_unitdir}

rm -rf %{buildroot}%{_initrddir}
install -Dpm 644 %{SOURCE2} %{buildroot}%{_sysusersdir}/%{name}.conf

%if %{with i18n}
%make_install PREFIX=/usr install-i18n
%find_lang %{name} --with-man
%endif

%pre
%sysusers_create_compat %{SOURCE2}

%post
%systemd_post dnsmasq.service

%preun
%systemd_preun dnsmasq.service

%postun
%systemd_postun_with_restart dnsmasq.service


%files
%license COPYING COPYING-v3
%doc CHANGELOG FAQ doc.html setup.html dbus/DBus-interface
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/trust-anchors.conf
%{_sbindir}/dnsmasq
%dir %{_sysconfdir}/dnsmasq.d
%config(noreplace) %{_sysconfdir}/dnsmasq.conf
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/dnsmasq.conf
%{_sysusersdir}/dnsmasq.conf
%{_unitdir}/%{name}.service
%dir %attr(0755,root,dnsmasq) %{_var}/lib/dnsmasq
%{_mandir}/man8/dnsmasq*

%files utils
%license COPYING COPYING-v3
%{_bindir}/dhcp_*
%{_mandir}/man1/dhcp_*

%if %{with i18n}
%files langpack -f %{name}.lang
%endif


%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.89-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.89-4
- Rebuilt for loongarch release

* Wed Jul 31 2024 Huang zien <ethanehuang@tencent.com> - 2.89-3
- [Type] security
- [DESC] Dnsmasq 2.9 is vulnerable to Integer Overflow via forward_query(fix cve-2023-49441)

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.89-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 24 2023 Wang Guodong <gordonwwang@tencent.com> - 2.89-1
- Upgrade to version 2.89

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.87-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.87-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Nov 24 2022 Miaojun Dong <zoedong@tencent.com> - 2.87-1
- Initial build
